==> zetascale-0.5.4-py3-none-any.whl: zeta/nn/__init__.py <==
# Copyright (c) 2022 Agora
# Licensed under The MIT License [see LICENSE for details]


# attention
from zeta.nn.architecture.transformer import  Decoder, Encoder, ViTransformerWrapper, Transformer
from zeta.nn.architecture.local_transformer import LocalTransformer
from zeta.nn.architecture.parallel_transformer import ParallelTransformerBlock
from zeta.nn.architecture.auto_regressive_wrapper import AutoregressiveWrapper
from zeta.nn.architecture.cross_attender import CrossAttender


######### Attention
from zeta.nn.attention.multiquery_attention import MultiQueryAttention
from zeta.nn import *
from zeta.nn.attention.cross_attention import CrossAttend
from zeta.nn.attention.multihead_attention import MultiheadAttention
from zeta.nn.attention.flash_attention2 import FlashAttentionTwo
from zeta.nn.attention.local_attention import LocalAttention
from zeta.nn.attention.local_attention_mha import LocalMHA



# embeddings
from zeta.nn.embeddings.rope import RotaryEmbedding
from zeta.nn.embeddings.xpos_relative_position import XPOS, rotate_every_two, apply_rotary_pos_emb

from zeta.nn.embeddings.multiway_network import MultiwayEmbedding, MultiwayNetwork, MultiwayWrapper
from zeta.nn.embeddings.bnb_embedding import BnBEmbedding
from zeta.nn.embeddings.base import BaseEmbedding
from zeta.nn.embeddings.nominal_embeddings import NominalEmbedding

# modules
from zeta.nn.modules.lora import Lora
from zeta.nn.modules.feedforward_network import FeedForwardNetwork
from zeta.nn.modules.droppath import DropPath
from zeta.nn.modules.token_learner import TokenLearner

==> zetascale-0.5.5-py3-none-any.whl: zeta/nn/__init__.py <==
# Copyright (c) 2022 Agora
# Licensed under The MIT License [see LICENSE for details]


# attention
from zeta.nn.architecture.transformer import  Decoder, Encoder, ViTransformerWrapper, Transformer
from zeta.nn.architecture.local_transformer import LocalTransformer
from zeta.nn.architecture.parallel_transformer import ParallelTransformerBlock
from zeta.nn.architecture.auto_regressive_wrapper import AutoregressiveWrapper
# from zeta.nn.architecture.cross_attender import CrossAttender


######### Attention
from zeta.nn.attention.multiquery_attention import MultiQueryAttention
from zeta.nn import *
# from zeta.nn.attention.cross_attention import CrossAttend
from zeta.nn.attention.multihead_attention import MultiheadAttention
from zeta.nn.attention.flash_attention2 import FlashAttentionTwo
from zeta.nn.attention.local_attention import LocalAttention
from zeta.nn.attention.local_attention_mha import LocalMHA



# embeddings
from zeta.nn.embeddings.rope import RotaryEmbedding
from zeta.nn.embeddings.xpos_relative_position import XPOS, rotate_every_two, apply_rotary_pos_emb

from zeta.nn.embeddings.multiway_network import MultiwayEmbedding, MultiwayNetwork, MultiwayWrapper
from zeta.nn.embeddings.bnb_embedding import BnBEmbedding
from zeta.nn.embeddings.base import BaseEmbedding
from zeta.nn.embeddings.nominal_embeddings import NominalEmbedding

# modules
from zeta.nn.modules.lora import Lora
from zeta.nn.modules.feedforward_network import FeedForwardNetwork
from zeta.nn.modules.droppath import DropPath
from zeta.nn.modules.token_learner import TokenLearner
